@@ -50,6 +50,19 @@ macro_rules! match_handler_response {
     };
 }
 
+#[non_exhaustive]
+#[derive(Clone, Copy, Debug, PartialEq, Eq)]
+/// Used for some functions to define which scope should be manipulated. 
+pub enum ManipulationScope{
+    /// Only apply changes locally
+    Local,
+    /// Apply changes locally and to Discord
+    All,
+    /// Only apply changes with Discord
+    Discord
+}
+
+#[cfg(feature = "handler")]
 #[derive(Clone)]
 /// The InteractionHandler is the 'thing' that will handle your incoming interactions.
 /// It does interaction validation (as required by Discord) and provides a pre-defined actix-web server
@@ -62,9 +75,12 @@ pub struct InteractionHandler {
 
     global_handles: HashMap<&'static str, HandlerFunction>,
     component_handles: HashMap<&'static str, HandlerFunction>,
+
+    // These handles are 'forgotten' every time the app is shutdown (whatever the reason may be).
     guild_handles: HashMap<Snowflake, HandlerFunction>,
 }
 
+#[cfg(feature = "handler")]
 // Only here to make Debug less generic, so I can send a reference
 impl fmt::Debug for InteractionHandler {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
@@ -77,6 +93,7 @@ impl fmt::Debug for InteractionHandler {
     }
 }
 
+#[cfg(feature = "handler")]
 impl InteractionHandler {
     /// Initalizes a new `InteractionHandler`
     pub fn new(
@@ -219,67 +236,106 @@ impl InteractionHandler {
     pub fn add_component_handle(&mut self, custom_id: &'static str, func: HandlerFunction) {
         self.component_handles.insert(custom_id, func);
     }
+    
 
     #[cfg(feature = "extended-handler")]
     #[cfg_attr(docsrs, doc(cfg(feature = "extended-handler")))]
-    /// Register an command with Discord!
-    pub async fn register_command_handle(
+    /// Register a guild-specific command with Discord!
+    /// 
+    /// # NOTE
+    /// Guild-specific commands are not cached or saved in any way by the handler. 
+    /// This means that between restarts, updates, crashes, or whatever that causes the app to terminate, the handler 'forgets' which command belonged to which handler.
+    pub async fn register_guild_handle(
         &mut self,
         guild: impl Into<Snowflake>,
-        cmd: ApplicationCommand,
+        cmd: &ApplicationCommand,
         func: HandlerFunction,
+        scope: &ManipulationScope
     ) -> Result<ApplicationCommand, HttpError> {
+        
         let g = guild.into();
+        match scope{
+            ManipulationScope::Local =>{
+                self.guild_handles.insert(g, func);
+                Ok(cmd.clone())
+            },
+            ManipulationScope::Discord |
+            ManipulationScope::All => {
+                let url = format!(
+                    "{}/applications/{}/guilds/{}/commands",
+                    crate::BASE_URL,
+                    self.application_id,
+                    g
+                );
+                
+                let r = self.client.post(&url).json(cmd).send().await;
+        
+                expect_successful_api_response_and_return!(r, ApplicationCommand, a, {
+                    if let Some(id) = a.id {
 
-        let url = format!(
-            "{}/applications/{}/guilds/{}/commands",
-            crate::BASE_URL,
-            self.application_id,
-            g
-        );
-
-        let r = self.client.post(&url).json(&cmd).send().await;
-
-        expect_successful_api_response_and_return!(r, ApplicationCommand, a, {
-            if let Some(id) = a.id {
-                // Already overwrites current key if it exists, so no need to check.
-                self.guild_handles.insert(id, func);
-                Ok(a)
-            } else {
-                // Pretty bad if this code reaches...
-                Err(HttpError {
-                    code: 0,
-                    message: "Command registration response did not have an ID.".to_string(),
+                        if scope == &ManipulationScope::All{
+                            // Already overwrites current key if it exists, so no need to check.
+                            self.guild_handles.insert(id, func);
+                        }
+                        
+                        Ok(a)
+                    } else {
+                        // Pretty bad if this code reaches...
+                        Err(HttpError {
+                            code: 0,
+                            message: "Command registration response did not have an ID.".to_string(),
+                        })
+                    }
                 })
-            }
-        })
+            },
+        }
+        
     }
 
     #[cfg(feature = "extended-handler")]
     #[cfg_attr(docsrs, doc(cfg(feature = "extended-handler")))]
     /// Remove a guild handle
-    pub async fn deregister_command_handle(
+    pub async fn deregister_guild_handle(
         &mut self,
         guild: impl Into<Snowflake>,
         id: impl Into<Snowflake>,
+        scope: &ManipulationScope,
     ) -> Result<(), HttpError> {
-        let g = guild.into();
+
         let i = id.into();
+        let g = guild.into();
 
-        let url = format!(
-            "{}/applications/{}/guilds/{}/commands/{}",
-            crate::BASE_URL,
-            self.application_id,
-            g,
-            i
-        );
+        match scope{
+            ManipulationScope::Local => {
+                self.guild_handles.remove(&i);
+                Ok(())
+            },
+            ManipulationScope::All |
+            ManipulationScope::Discord => {
+                let url = format!(
+                    "{}/applications/{}/guilds/{}/commands/{}",
+                    crate::BASE_URL,
+                    self.application_id,
+                    g,
+                    i
+                );
+        
+                let r = self.client.delete(&url).send().await;
+        
+                expect_specific_api_response!(r, StatusCode::NO_CONTENT, {
+                    if scope == &ManipulationScope::All{
+                        self.guild_handles.remove(&i);
+                    }
+        
+                    Ok(())
+                })
+            },
+        }
 
-        let r = self.client.delete(&url).send().await;
+        
+        
 
-        expect_specific_api_response!(r, StatusCode::NO_CONTENT, {
-            self.guild_handles.remove(&i);
-            Ok(())
-        })
+        
     }
 
     /// Entry point function for handling `Interactions`
@@ -447,7 +503,7 @@ impl InteractionHandler {
                 ),
             )
         })
-        .bind(("0.0.0.0:{}", port))?
+        .bind(format!("0.0.0.0:{}", port))?
         .run()
         .await
     }
