@@ -5,7 +5,7 @@ use serde_with::*;
 use ::chrono::{DateTime, Utc};
 
 #[cfg(feature = "handler")]
-use log::error;
+use log::{warn};
 
 // ======== Structures =========
 #[serde_as]
@@ -155,9 +155,9 @@ impl From<u32> for Color {
     }
 }
 
-impl Into<u32> for Color {
-    fn into(self) -> u32 {
-        ((self.red as u32) << 16) | ((self.green as u32) << 8) | self.blue as u32
+impl From<Color> for u32 {
+    fn from(c: Color) -> u32 {
+        ((c.red as u32) << 16) | ((c.green as u32) << 8) | c.blue as u32
     }
 }
 
@@ -238,7 +238,7 @@ impl EmbedBuilder {
             }
             Some(ref mut f) => {
                 if f.len() >= 25 {
-                    error!("Field limit reached. Ignoring");
+                    warn!("Field limit reached. Ignoring");
                 } else {
                     f.push(field);
                 }
